==> holy-8.x-1.5.tar.gz: holy/README.md <==
# HOLY - athomic theme

This a stratup theme for your project.

Recpect Brad Frost idea
https://bradfrost.com/blog/post/atomic-web-design/


# DRUPAL WAY

Holy theme is applicable to frontend project.
Base theme is classy
The goal is style standard profile instlation.


# GULP

You need install Node JS (https://nodejs.org/en/) to your computer.

a, Go to theme holy, where is file package.json and install npm modules to your theme.

> npm install

b, compile sass to css

> gulp


# GULP LIBRARIES
"browserslist"
"gulp"
"gulp-autoprefixer"
"gulp-sass"
"gulp-sass-glob"

These are the basic npm components for compile SASS to CSS.


# ATOMIC FLODER

The use floder is fundamental. 
It makes you think about atomic structure.

01-atoms
02-molecules
03-organisms
04-layouts
05-pages


# SASS COMPONENTS

[components]
    [01-atoms]
        _form.scss
        _typo.scss
    [02-molecules]
        [block]
            _block--breadcrumb.scss
        [field]
            _field--name-field-tags.scss
            _field--name-title.scss
            _field--type-comment.scss
            _field--type-image.scss
        [node]
            .gitkeep
        [view]  
            _view--frontpage.scss
        _block.scss
        _field.scss
        _menu.scss
        _messages.scss
        _node.scss
        _pager.scss
        _tabs.scss
        _view.scss
    [03-organisms]
        [copyright]
            [block]
                .gitkeep
            _copyright--block.scss
            _copyright--region.scss
        [footer]
            [block]
                _footer-block--branding.scss
                _footer-block--menu.scss
            _footer--block.scss
            _footer--region.scss
        [header]
            [block]
                _header-block--branding.scss
                _header-block--language.scss
                _header-block--search.scss
            _header--block.scss
            _header--region.scss
        [hero]
            [block]
                _hero-block--pagetitle.scss
            _hero--block.scss
            _hero--region.scss
        [main]
            [block]
                .gitkeep
            [field]
                .gitkeep
            [node]
                _main-node--full.scss
                _main-node--teaser.scss
            [search]
                _main-search--results.scss
            [user]
                _main-user--login.scss
                _main-user--pass.scss
                _main-user--register.scss
            [view]
                .gitkeep
            _main--block.scss
            _main--region.scss            
        [menu]
            [block]
                _menu-block--menu.scss
            _menu--block.scss
            _menu--region.scss
        [navbar]
            [block]
                _navbar-block--branding.scss
            _navbar--block.scss
            _navbar--icons.scss
            _navbar--region.scss
        [sidebar]
            [block]
                _sidebar-block--menu.scss
            _sidebar--block.scss
            _sidebar--region.scss
        _copyright.scss
        _footer.scss
        _header.scss
        _hero.scss
        _main.scss
        _menu.scss
        _navbar.scss
        _sidebar.scss
    [04-layouts]
        _container.scss
        _layout.scss
        _navbar-collapse.scss
    [05-pages]
        _frontpage.scss
_fonts.scss
_variables.scss
_class.scss
_global.scss
ckeditor.scss
style.scss


# RULES

(1) FILE NAMES
--------------

a, _element-name.scss
b, _floder--element-name.scss
c, _floder-floder--element-name.scss


(2 FILE HEADER COMMENT
----------------------

a,
// 
// element-name 
// 

b,
// 
// FLODER -- element-name 
// 

c,
// 
// FLODER - FLODER -- element-name 
// 

(3) FILE CONTENTS
-----------------

a,
element-name {

}

b,
floder {

    element-name {

    }    

}

c, 
floder {

    floder {

        element-name {

        }    

    }

}

# STYLE.SCSS

NOTE: 
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after floder content

@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

@import 'components/01-atoms/**/*';
@import 'components/02-molecules/**/*';
@import 'components/03-organisms/**/*';
@import 'components/04-layouts/**/*';
@import 'components/05-pages/**/*';


# CKEDITOR.SCSS

NOTE: 
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after floder content

.cke_editable {
    padding: 25px;
}

@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

// components
@import 'components/01-atoms/typo';


# TEMPLATES

Holy respect classy base theme templates structure.
It only fills new needed template.

==> holy-8.x-1.7.tar.gz: holy/README.md <==
# HOLY - atomic theme

This a stratup theme for your project.

Recpect Brad Frost idea\
https://bradfrost.com/blog/post/atomic-web-design/


# DRUPAL WAY

- Holy theme is applicable to frontend project.
- Base theme is classy
- The goal is style standard profile instalation.


# GULP

You need install Node JS (https://nodejs.org/en/) to your computer.

a, Go to theme holy, where is file package.json and install npm modules to your theme.

```
> npm install
```

b, compile sass to css

```
> gulp
```

# GULP LIBRARIES

```
"browserslist"
"gulp"
"gulp-autoprefixer"
"gulp-sass"
"gulp-sass-glob"
```

These are the basic npm components for compile SASS to CSS.


# ATOMIC FLODER

The use floder is fundamental.\
It makes you think about atomic structure.

```
01-atoms
02-molecules
03-organisms
04-layouts
05-pages
```

# SASS COMPONENTS

```
[components]
    [01-atoms]
        _audio.scss
        _blockquote.scss
        _body.scss
        _form.scss
        _hr.scss
        _html.scss
        _img.scss
        _link.scss
        _list.scss
        _paragraph.scss
        _table.scss
        _title.scss
        _video.scss
    [02-molecules]
        [block]
            _block--breadcrumb.scss
        [field]
            _field--name-field-tags.scss
            _field--name-title.scss
            _field--type-comment.scss
            _field--type-image.scss
        [node]
            .gitkeep
        [view]  
            _view--frontpage.scss
        _block.scss
        _field.scss
        _menu.scss
        _messages.scss
        _node.scss
        _pager.scss
        _tabs.scss
        _view.scss
    [03-organisms]
        [copyright]
            .gitkeep
        [footer]
            _footer-block--branding.scss
            _footer-block--menu.scss
        [header]
            _header-block--branding.scss
            _header-block--language.scss
            _header-block--search.scss
        [hero]
            _hero-block--pagetitle.scss
        [main]
            _main-node--full.scss
            _main-node--teaser.scss
            _main-search--results.scss
            _main-user--login.scss
            _main-user--pass.scss
            _main-user--register.scss
        [menu]
            _menu-block--menu.scss
        [navbar]
            _navbar-block--branding.scss
            _navbar-icons.scss
        [sidebar]
            _sidebar-block--menu.scss
        _copyright.scss
        _footer.scss
        _header.scss
        _hero.scss
        _main.scss
        _menu.scss
        _navbar.scss
        _sidebar.scss
    [04-layouts]
        _body.scss
        _container.scss
        _layout.scss
        _navbar-collapse.scss
    [05-pages]
        _frontpage.scss
_class.scss
_color.scss
_fonts.scss
_global.scss
_variables.scss
ckeditor.scss
style.scss
```

# RULES

(1) FILE NAMES
--------------
Location determines file name

```
example:

a, _name.scss
b, _floder--name.scss
c, _floder-floder--name.scss
```

(2) FILE HEADER COMMENT
----------------------
Location determines header comment

```
example:

a,
// 
// name 
// 

b,
// 
// FLODER -- name 
// 

c,
// 
// FLODER - FLODER -- name 
// 
```

(3) FILE CONTENTS
-----------------
Location determines root selector

```
.name-selector {

  // any code

}

#floder {

    .name-selector {

      // any code

    }    

}
```

# STYLE.SCSS

NOTE:
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after floder content

```
@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

@import 'components/01-atoms/**/*';
@import 'components/02-molecules/**/*';
@import 'components/03-organisms/**/*';
@import 'components/04-layouts/**/*';
@import 'components/05-pages/**/*';
```

# CKEDITOR.SCSS

NOTE:
- order is important for the function and priority of selectors
- gulp-sass-glob / first compile file, after floder content

```
.cke_editable {
    padding: 25px;
}

@import 'fonts';
@import 'variables';
@import 'global';
@import 'class';

// components
@import 'components/01-atoms/typo';
```

# TEMPLATES

Holy respect classy base theme templates structure.\
It only fills new needed template.
